diff --git a/src/common/helpers.py b/src/common/helpers.py
index a5574cc96debb494bb9540798138ef8476d60f4c..c7593d562f767a8dcb84e2979e1c21fe9aa3ad7f 100644
--- a/src/common/helpers.py
+++ b/src/common/helpers.py
@@ -692,8 +692,11 @@ def get_os_info():
 					text = fd.readline().strip() # get only first line
 					fd.close()
 					if path_to_file.endswith('version'):
-						# sourcemage_version has all the info we need
-						if not os.path.basename(path_to_file).startswith('sourcemage'):
+						# sourcemage_version and slackware-version files
+						# have all the info we need (name and version of distro)
+						if not os.path.basename(path_to_file).startswith(
+						'sourcemage') or not\
+						os.path.basename(path_to_file).startswith('slackware'):
 							text = distro_name + ' ' + text
 					elif path_to_file.endswith('aurox-release'):
 						# file doesn't have version